Module ll

Module ll 

Re-exports

pub use mscript_12_3_5 as miniscript;

Enums

Content
Error

Functions

check_offset
check_offset_lookahead
decode_derivation_paths
Expects a payload following this format: <DERIVATION_PATHS><..>
decode_v1
Expects a payload following this format: <DERIVATION_PATHS><INDIVIDUAL_SECRETS><ENCRYPTED_PAYLOAD><..>
decode_version
Expects a payload following this format: <..>
decrypt_aes_gcm_256_v1
decryption_secret
encode_derivation_paths
Encode following this format: <DERIVATION_PATH_1><DERIVATION_PATH_2><..><DERIVATION_PATH_N>
encode_encrypted_payload
Encode following this format:
encode_individual_secrets
Encode following this format: <INDIVIDUAL_SECRET_1><INDIVIDUAL_SECRET_2><..><INDIVIDUAL_SECRET_N>
encode_v1
Encode following this format <DERIVATION_PATHS><INDIVIDUAL_SECRETS><ENCRYPTED_PAYLOAD> NOTE: payload that will fail to decode can be encoded with this function, for instance with an invalid version, the inputs args must be sanitized by the caller.
encrypt_aes_gcm_256_v1
increment_offset
individual_secret
individual_secrets
init_offset
inner_encrypt
nonce
parse_content_metadata
parse_derivation_paths
Expects to parse a payload of the form: <CHILD_COUNT><..> <..> <CHILD_COUNT><..> <..>
parse_encrypted_payload
Expects to parse a payload of the form: <..>
parse_encryption
parse_individual_secrets
Expects to parse a payload of the form: <INDIVIDUAL_SECRET> <..> <INDIVIDUAL_SECRET> <..>
parse_magic_byte
parse_version
try_decrypt_aes_gcm_256
xor