encode_v1

Function encode_v1 

pub fn encode_v1(
    version: u8,
    derivation_paths: Vec<u8>,
    individual_secrets: Vec<u8>,
    encryption: u8,
    encrypted_payload: Vec<u8>,
) -> Vec<u8> 
Encode following this format <DERIVATION_PATHS><INDIVIDUAL_SECRETS><ENCRYPTED_PAYLOAD> NOTE: payload that will fail to decode can be encoded with this function, for instance with an invalid version, the inputs args must be sanitized by the caller.