Re-exports
pub use mscript_12_3_5 as miniscript;
Enums
Functions
- check_
offset - check_
offset_ lookahead - decode_
derivation_ paths - Expects a payload following this format:
<DERIVATION_PATHS><..> - decode_
v1 - Expects a payload following this format:
<DERIVATION_PATHS><INDIVIDUAL_SECRETS> <ENCRYPTED_PAYLOAD><..> - decode_
version - Expects a payload following this format:
<..> - decrypt_
aes_ gcm_ 256_ v1 - decryption_
secret - encode_
derivation_ paths - Encode following this format:
<DERIVATION_PATH_1><DERIVATION_PATH_2><..><DERIVATION_PATH_N> - encode_
encrypted_ payload - Encode following this format:
- encode_
individual_ secrets - Encode following this format:
<INDIVIDUAL_SECRET_1><INDIVIDUAL_SECRET_2><..><INDIVIDUAL_SECRET_N> - encode_
v1 - Encode following this format
<DERIVATION_PATHS><INDIVIDUAL_SECRETS> <ENCRYPTED_PAYLOAD> NOTE: payload that will fail to decode can be encoded with this function, for instance with an invalid version, the inputs args must be sanitized by the caller. - encrypt_
aes_ gcm_ 256_ v1 - increment_
offset - individual_
secret - individual_
secrets - init_
offset - inner_
encrypt - nonce
- parse_
content_ metadata - parse_
derivation_ paths - Expects to parse a payload of the form:
<CHILD_COUNT> <..> <..> <CHILD_COUNT> <..> <..> - parse_
encrypted_ payload - Expects to parse a payload of the form:
<..> - parse_
encryption - parse_
individual_ secrets - Expects to parse a payload of the form:
<INDIVIDUAL_SECRET> <..> <INDIVIDUAL_SECRET> <..> - parse_
magic_ byte - parse_
version - try_
decrypt_ aes_ gcm_ 256 - xor